@@ -9,5 +9,9 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
+#import os
+#os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
+
 from jax.config import config
 config.update("jax_enable_x64", True)  # double precision in jax by default
+config.update('jax_platform_name', 'cpu')
