@@ -13,6 +13,8 @@ import sys
 import argparse
 import pprint
 
+from . import init
+
 from jax import numpy as np
 import numpy as onp
 import uproot
@@ -34,8 +36,8 @@ def resample(
     pidgen = "pidgen", 
     stat = "pidstat", 
     maxfiles = 0, 
-    start = 0, 
-    stop = -1, 
+    start = None, 
+    stop = None, 
     usecache = False, 
     plot = False, 
     interactive = False, 
@@ -81,7 +83,7 @@ def resample(
   start_event = start
   stop_event = stop
 
-  if stop_event > len(input_data) : stop_event = len(input_data)
+  if (stop_event is not None) and stop_event > len(input_data) : stop_event = len(input_data)
   else : input_data = input_data[start_event:stop_event]
   if (verbose) : print (f"Shape of the array for resampling: {input_data.shape}")
 
