@@ -10,7 +10,7 @@
 ###############################################################################
 
 variable = {
-    "branch" : "probe_PIDmu", 
+    "expression" : "probe_PIDmu", 
     "data_range" : (-20., 20.), 
     "transform_forward" : "x", 
     "transform_backward" : "x", 
